[Libreoffice-commits] online.git: Branch 'distro/collabora/collabora-online-1-0' - 2 commits - loleaflet/dist loleaflet/src loolwsd/loolwsd-systemplate-setup

Pranav Kant pranavk at collabora.co.uk
Wed Jun 29 14:41:03 UTC 2016


 loleaflet/dist/loleaflet.html            |    3 +++
 loleaflet/src/control/Control.Menubar.js |    8 +++++++-
 loolwsd/loolwsd-systemplate-setup        |    4 ++--
 3 files changed, 12 insertions(+), 3 deletions(-)

New commits:
commit f4b713c82a26772db5b99980b9809285fc8c4b7e
Author: Pranav Kant <pranavk at collabora.co.uk>
Date:   Wed Jun 29 19:31:26 2016 +0530

    loolwsd: Follow symlinks while copying fonts into systemplate
    
    Change-Id: Iee7f5b1dd3cb1884ac51f58c1b6c1ba2b73a7c30
    (cherry picked from commit d60da277e837ff2dcc988a9cdccf35c9b9f66199)

diff --git a/loolwsd/loolwsd-systemplate-setup b/loolwsd/loolwsd-systemplate-setup
index 27c760c..0d30524 100755
--- a/loolwsd/loolwsd-systemplate-setup
+++ b/loolwsd/loolwsd-systemplate-setup
@@ -80,11 +80,11 @@ mkdir -p $CHROOT/usr/bin/
 cd $CHROOT || exit 1
 
 mkdir -p usr/share || exit 1
-cp -r -p /usr/share/fonts usr/share
+cp -r -p -L /usr/share/fonts usr/share
 
 if [ -h usr/share/fonts/ghostscript ]; then
     mkdir usr/share/ghostscript || exit 1
-    cp -r -p /usr/share/ghostscript/fonts usr/share/ghostscript
+    cp -r -p -L /usr/share/ghostscript/fonts usr/share/ghostscript
 fi
 
 # Debugging only hackery to avoid confusion.
commit 0e492ecb683aebae9b679f69128f9bca74c320a0
Author: Pranav Kant <pranavk at collabora.co.uk>
Date:   Wed Jun 29 17:40:07 2016 +0530

    loleaflet: Disable revision history option by default
    
    Hosts are supposed to provide 'revisionhistory' parameter when
    calling loleaflet.html
    
    Change-Id: I6c1a89b602a739c0d30b7aeea680b4c577b37cc4
    (cherry picked from commit 277c191eb0d99ab0406b497cf773f637b40cd8f8)

diff --git a/loleaflet/dist/loleaflet.html b/loleaflet/dist/loleaflet.html
index 21cd01e..d66e7df 100644
--- a/loleaflet/dist/loleaflet.html
+++ b/loleaflet/dist/loleaflet.html
@@ -105,7 +105,10 @@
     var host = '%HOST%';
     var permission = getParameterByName('permission') || 'edit';
     var timestamp = getParameterByName('timestamp');
+    <!-- Shows close button if non-zero value provided -->
     var closebutton = getParameterByName('closebutton');
+    <!-- Shows revision history file menu option -->
+    var revHistoryEnabled = getParameterByName('revisionhistory');
     if (wopiSrc === '' && filePath === '') {
         vex.dialog.alert(wrongwopisrc);
     }
diff --git a/loleaflet/src/control/Control.Menubar.js b/loleaflet/src/control/Control.Menubar.js
index 5f3629e..49a28aa 100644
--- a/loleaflet/src/control/Control.Menubar.js
+++ b/loleaflet/src/control/Control.Menubar.js
@@ -2,7 +2,7 @@
 * Control.Menubar
 */
 
 /* global $ _ map title vex */
 L.Control.Menubar = L.Control.extend({
 	// TODO: Some mechanism to stop the need to copy duplicate menus (eg. Help)
 	options: {
@@ -330,6 +330,12 @@ L.Control.Menubar = L.Control.extend({
 	_createMenu: function(menu) {
 		var itemList = [];
 		for (var i in menu) {
+			if (menu[i].type === 'action' &&
+			    menu[i].id === 'rev-history' &&
+			    !revHistoryEnabled) {
+				continue;
+			}
+
 			var liItem = L.DomUtil.create('li', '');
 			var aItem = L.DomUtil.create('a', '', liItem);
 			aItem.innerHTML = menu[i].name;
@@ -2,7 +2,7 @@
 */
 
-/* global $ _ map title vex */
+/* global $ _ map title vex revHistoryEnabled */
 L.Control.Menubar = L.Control.extend({
 	// TODO: Some mechanism to stop the need to copy duplicate menus (eg. Help)


More information about the Libreoffice-commits mailing list